Struct
QmiMessageFoxGetFirmwareVersionOutput
since: 1.32
Description [src]
struct QmiMessageFoxGetFirmwareVersionOutput {
/* No available fields */
}
The QmiMessageFoxGetFirmwareVersionOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.32
Instance methods
qmi_message_fox_get_firmware_version_output_get_result
Get the result of the QMI operation.
since: 1.32
qmi_message_fox_get_firmware_version_output_get_version
Get the ‘Version’ field from self.
since: 1.32
qmi_message_fox_get_firmware_version_output_ref
Atomically increments the reference count of self by one.
since: 1.32
qmi_message_fox_get_firmware_version_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.32