Struct
QmiMessageVoiceStopContinuousDtmfInput
since: 1.32
Description [src]
struct QmiMessageVoiceStopContinuousDtmfInput {
/* No available fields */
}
The QmiMessageVoiceStopContinuousDtmfInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.32
Constructors
qmi_message_voice_stop_continuous_dtmf_input_new
Allocates a new QmiMessageVoiceStopContinuousDtmfInput.
since: 1.32
Instance methods
qmi_message_voice_stop_continuous_dtmf_input_ref
Atomically increments the reference count of self by one.
since: 1.32
qmi_message_voice_stop_continuous_dtmf_input_set_data
Set the ‘Data’ field in the message.
since: 1.32
qmi_message_voice_stop_continuous_dtmf_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.32